/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: jobgetdatedtransfers_be.h 935 2006-02-14 02:11:55Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_JOBGETDATEDTRANSFERS_BE_H
#define AQBANKING_JOBGETDATEDTRANSFERS_BE_H


#include <aqbanking/job.h>
#include <aqbanking/jobgetdatedtransfers.h>


#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#endif /* AQBANKING_JOBGETDATEDTRANSFERS_BE_H */

